summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldercachedimap.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/kmfoldercachedimap.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmfoldercachedimap.h')
-rw-r--r--kmail/kmfoldercachedimap.h36
1 files changed, 19 insertions, 17 deletions
diff --git a/kmail/kmfoldercachedimap.h b/kmail/kmfoldercachedimap.h
index 61fcfcba..87c15f75 100644
--- a/kmail/kmfoldercachedimap.h
+++ b/kmail/kmfoldercachedimap.h
@@ -19,11 +19,11 @@
*
* In addition, as a special exception, the copyright holders give
* permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
- * Qt. If you modify this file, you may extend this exception to
+ * TQt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from
* your version.
@@ -66,6 +66,7 @@ using KMail::AttachmentStrategy;
class DImapTroubleShootDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
enum SelectedOperation {
None = -1,
@@ -75,7 +76,7 @@ public:
RefreshCache
};
- DImapTroubleShootDialog( TQWidget* parent=0, const char* name=0 );
+ DImapTroubleShootDialog( TQWidget* tqparent=0, const char* name=0 );
static int run();
@@ -92,14 +93,15 @@ private:
class KMFolderCachedImap : public KMFolderMaildir
{
Q_OBJECT
+ TQ_OBJECT
public:
static TQString cacheLocation() {
return locateLocal("data", "kmail/dimap" );
}
- /** Usually a parent is given. But in some cases there is no
- fitting parent object available. Then the name of the folder
+ /** Usually a tqparent is given. But in some cases there is no
+ fitting tqparent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderCachedImap(KMFolder* folder, const char* name=0);
virtual ~KMFolderCachedImap();
@@ -108,7 +110,7 @@ public:
void reallyDoClose(const char* owner);
/** Initialize this storage from another one. Used when creating a child folder */
- void initializeFrom( KMFolderCachedImap* parent );
+ void initializeFrom( KMFolderCachedImap* tqparent );
virtual void readConfig();
virtual void writeConfig();
@@ -283,8 +285,8 @@ public:
void setACLList( const ACLList& arr );
// Reimplemented so the mStatusChangedLocally bool can be set
- virtual void seStatus( int id, KMMsgStatus status, bool toggle );
- virtual void seStatus( TQValueList<int>& ids, KMMsgStatus status, bool toggle );
+ virtual void setqStatus( int id, KMMsgtqStatus status, bool toggle );
+ virtual void setqStatus( TQValueList<int>& ids, KMMsgtqStatus status, bool toggle );
TQString annotationFolderType() const { return mAnnotationFolderType; }
@@ -322,7 +324,7 @@ public:
/**
* Specify an imap path that is used to create the folder on the server
* Otherwise the parent folder is used to construct the path
*/
const TQString& imapPathForCreation() { return mImapPathCreation; }
void setImapPathForCreation( const TQString& path ) { mImapPathCreation = path; }
@@ -403,9 +405,9 @@ protected:
virtual void timerEvent( TQTimerEvent* );
/* update progress status */
- void newState( int progress, const TQString& syncStatus );
+ void newState( int progress, const TQString& synctqStatus );
- /** See if there is a better parent then this folder */
+ /** See if there is a better tqparent then this folder */
KMFolderCachedImap* findParent( const TQString& path, const TQString& name );
@@ -472,8 +474,8 @@ private:
/**
* Sync the next subfolder in the list of subfolders (mSubfoldersForSync).
* When finished, this will switch either to the state SYNC_STATE_GET_SUBFOLDER_QUOTA or
* to SYNC_STATE_GET_QUOTA.
*/
void syncNextSubFolder( bool secondSync );
@@ -503,13 +505,13 @@ private:
SYNC_STATE_SET_ANNOTATIONS,
SYNC_STATE_GET_ACLS,
SYNC_STATE_SET_ACLS,
- SYNC_STATE_GET_QUOTA,
+ SYNC_STATE_GET_TQUOTA,
SYNC_STATE_FIND_SUBFOLDERS,
SYNC_STATE_SYNC_SUBFOLDERS,
SYNC_STATE_CHECK_UIDVALIDITY,
SYNC_STATE_RENAME_FOLDER,
SYNC_STATE_CLOSE,
- SYNC_STATE_GET_SUBFOLDER_QUOTA
+ SYNC_STATE_GET_SUBFOLDER_TQUOTA
} mSyncState;
int mProgress;
@@ -588,7 +590,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
* UIDs added by seStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status
* of the mails in this folder.
@@ -322,7 +324,7 @@ public:
/**
* Specify an imap path that is used to create the folder on the server
- * Otherwise the parent folder is used to construct the path
+ * Otherwise the tqparent folder is used to construct the path
*/
const TQString& imapPathForCreation() { return mImapPathCreation; }
@@ -472,8 +474,8 @@ private:
/**
* Sync the next subfolder in the list of subfolders (mSubfoldersForSync).
- * When finished, this will switch either to the state SYNC_STATE_GET_SUBFOLDER_QUOTA or
- * to SYNC_STATE_GET_QUOTA.
+ * When finished, this will switch either to the state SYNC_STATE_GET_SUBFOLDER_TQUOTA or
+ * to SYNC_STATE_GET_TQUOTA.
*/
void syncNextSubFolder( bool secondSync );
@@ -588,7 +590,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
- * UIDs added by seStatus. Indicates that the client has changed
+ * UIDs added by setqStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status